==> docz-theme-umi-2.0.4.tgz: package/es/components/ui/Page.js <==
import * as React from 'react';
import { Fragment } from 'react';
import { useConfig, Link } from 'docz';
import Edit from 'react-feather/dist/icons/edit-2';
import styled from 'styled-components';
import { ButtonLink } from "./Button";
import { GithubLink, Sidebar, Main } from "../shared";
import { get } from "../../utils/theme";
import { mq } from "../../styles/responsive";
var Wrapper = styled.div.withConfig({
  displayName: "Page__Wrapper"
})(["flex:1;color:", ";background:", ";min-width:0;position:relative;display:flex;flex-direction:row;"], get('colors.text'), get('colors.background'));
export var Container = styled.div.withConfig({
  displayName: "Page__Container"
})(["box-sizing:border-box;", " ", ";"], function (props) {
  return mq({
    width: props.fullpage ? ['100%', '100%', '100%'] : ['100%', 'calc(100% - 224px)', 'calc(100% - 224px)'],
    padding: ['20px', '0 24px 24px']
  });
}, get('styles.container'));
var EditPage = styled(ButtonLink.withComponent('a')).withConfig({
  displayName: "Page__EditPage"
})(["display:flex;align-items:center;justify-content:center;position:absolute;padding:2px 8px;margin:8px;border-radius:", ";border:1px solid ", ";opacity:0.7;transition:opacity 0.4s;font-size:14px;color:", ";text-decoration:none;text-transform:uppercase;&:hover{opacity:1;background:", ";}", ";"], get('radii'), get('colors.border'), get('colors.text'), get('colors.border'), mq({
  visibility: ['hidden', 'hidden', 'visible'],
  top: [0, -60, 32],
  right: [0, 0, 40]
}));
var EditIcon = styled(Edit).withConfig({
  displayName: "Page__EditIcon"
})(["margin-right:5px;"]);
var AnchorWrapper = styled.div.withConfig({
  displayName: "Page__AnchorWrapper"
})(["position:relative;padding-top:24px;min-width:224px;> div{position:fixed;}"]);
var Anchor = styled.div.withConfig({
  displayName: "Page__Anchor"
})(["border-left:1px solid #f0f0f0;border-color:", ";padding-left:16px;line-height:20px;min-width:224px;padding-top:4px;padding-bottom:4px;"], function (props) {
  return props.hash.slice(1) === props.slug ? get('colors.blue') : '#f0f0f0';
});
var LinkWrapper = styled(Link).withConfig({
  displayName: "Page__LinkWrapper"
})(["font-size:12px;"]);
export var Page = function Page(_ref) {
  var children = _ref.children,
      _ref$doc = _ref.doc,
      link = _ref$doc.link,
      fullpage = _ref$doc.fullpage,
      _ref$doc$edit = _ref$doc.edit,
      edit = _ref$doc$edit === void 0 ? true : _ref$doc$edit,
      headings = _ref$doc.headings;

  var _useConfig = useConfig(),
      repository = _useConfig.repository;

  var content = React.createElement(Fragment, null, link && edit && React.createElement(EditPage, {
    href: link,
    target: "_blank"
  }, React.createElement(EditIcon, {
    width: 14
  }), " Edit page"), children); // 右侧锚点只跟踪 h2

  var anchors = headings.filter(function (v) {
    return v.depth === 2;
  });
  var _location = location,
      pathname = _location.pathname,
      hash = _location.hash;
  return React.createElement(Main, null, repository && React.createElement(GithubLink, {
    repository: repository
  }), !fullpage && React.createElement(Sidebar, null), React.createElement(Wrapper, null, fullpage ? React.createElement(Container, {
    fullpage: true
  }, content) : React.createElement(React.Fragment, null, React.createElement(Container, null, content), React.createElement(AnchorWrapper, null, React.createElement("div", null, anchors.map(function (a) {
    return React.createElement(Anchor, {
      key: a.slug,
      hash: hash,
      slug: a.slug
    }, React.createElement(LinkWrapper, {
      to: "".concat(pathname, "#").concat(a.slug),
      style: {
        color: hash === "#".concat(a.slug) ? '#1890ff' : 'rgba(0,0,0,.65)'
      }
    }, a.value));
  }))))));
};

==> docz-theme-umi-2.0.5.tgz: package/es/components/ui/Page.js <==
import * as React from 'react';
import { Fragment } from 'react';
import { useConfig, Link } from 'docz';
import Edit from 'react-feather/dist/icons/edit-2';
import styled from 'styled-components';
import { ButtonLink } from "./Button";
import { GithubLink, Sidebar, Main } from "../shared";
import { get } from "../../utils/theme";
import { mq } from "../../styles/responsive";
var Wrapper = styled.div.withConfig({
  displayName: "Page__Wrapper"
})(["flex:1;color:", ";background:", ";min-width:0;position:relative;display:flex;flex-direction:row;"], get('colors.text'), get('colors.background'));
export var Container = styled.div.withConfig({
  displayName: "Page__Container"
})(["box-sizing:border-box;", " ", ";"], function (props) {
  return mq({
    width: props.fullpage ? ['100%', '100%', '100%'] : ['100%', 'calc(100% - 113px)', 'calc(100% - 113px)'],
    padding: ['20px', '0 24px 24px']
  });
}, get('styles.container'));
var EditPage = styled(ButtonLink.withComponent('a')).withConfig({
  displayName: "Page__EditPage"
})(["display:flex;align-items:center;justify-content:center;position:absolute;padding:2px 8px;margin:8px;border-radius:", ";border:1px solid ", ";opacity:0.7;transition:opacity 0.4s;font-size:14px;color:", ";text-decoration:none;text-transform:uppercase;&:hover{opacity:1;background:", ";}", ";"], get('radii'), get('colors.border'), get('colors.text'), get('colors.border'), mq({
  visibility: ['hidden', 'hidden', 'visible'],
  top: [0, -60, 32],
  right: [0, 0, 40]
}));
var EditIcon = styled(Edit).withConfig({
  displayName: "Page__EditIcon"
})(["margin-right:5px;"]);
var AnchorWrapper = styled.div.withConfig({
  displayName: "Page__AnchorWrapper"
})(["position:relative;padding-top:24px;> div{position:fixed;}"]);
var Anchor = styled.div.withConfig({
  displayName: "Page__Anchor"
})(["border-left:1px solid #f0f0f0;border-color:", ";line-height:20px;padding:4px 16px;> a{width:80px;display:block;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;}"], function (props) {
  return props.hash.slice(1) === props.slug ? get('colors.blue') : '#f0f0f0';
});
var LinkWrapper = styled(Link).withConfig({
  displayName: "Page__LinkWrapper"
})(["font-size:12px;"]);
export var Page = function Page(_ref) {
  var children = _ref.children,
      _ref$doc = _ref.doc,
      link = _ref$doc.link,
      fullpage = _ref$doc.fullpage,
      _ref$doc$edit = _ref$doc.edit,
      edit = _ref$doc$edit === void 0 ? true : _ref$doc$edit,
      headings = _ref$doc.headings;

  var _useConfig = useConfig(),
      repository = _useConfig.repository;

  var content = React.createElement(Fragment, null, link && edit && React.createElement(EditPage, {
    href: link,
    target: "_blank"
  }, React.createElement(EditIcon, {
    width: 14
  }), " Edit page"), children); // 右侧锚点只跟踪 h2

  var anchors = headings.filter(function (v) {
    return v.depth === 2;
  });
  var _location = location,
      pathname = _location.pathname,
      hash = _location.hash;
  return React.createElement(Main, null, repository && React.createElement(GithubLink, {
    repository: repository
  }), !fullpage && React.createElement(Sidebar, null), React.createElement(Wrapper, null, fullpage ? React.createElement(Container, {
    fullpage: true
  }, content) : React.createElement(React.Fragment, null, React.createElement(Container, null, content), React.createElement(AnchorWrapper, null, React.createElement("div", null, anchors.map(function (a) {
    return React.createElement(Anchor, {
      key: a.slug,
      hash: hash,
      slug: a.slug
    }, React.createElement(LinkWrapper, {
      to: "".concat(pathname, "#").concat(a.slug),
      style: {
        color: hash === "#".concat(a.slug) ? '#1890ff' : 'rgba(0,0,0,.65)'
      }
    }, a.value));
  }))))));
};
